@@ -118,8 +118,15 @@ class OBDPort:
              print self.get_result()
              wx.PostEvent(self._notify_window, DebugEvent([2,"ate0 response:" + self.get_result()]))
 
+             self.send_command("at sp 0")  
+             time.sleep(0.3)
+             print self.get_result()
+             wx.PostEvent(self._notify_window, DebugEvent([2,"atsp0 response:" + self.get_result()]))
+
+             time.sleep(0.1)
+
              self.send_command("0100")
-             time.sleep(0.2)
+             time.sleep(0.3)
              ready = self.get_result()
              print ready
              time.sleep(1.2)
@@ -130,22 +137,31 @@ class OBDPort:
 
 
              if ready=="SEARCHING...":
-                time.sleep(1.2)
+                time.sleep(1.5)
+                ready = self.get_result()
+                time.sleep(0.3)
 
-             if ready=="BUSINIT: ...OK":
-                ready=self.get_result()
+             if ready=="BUS INIT: OK":
+                #ready=self.get_result()
                 print "Now: "+ready
                 wx.PostEvent(self._notify_window, DebugEvent([2,"0100 response2:" + ready]))
                 return None
+
+             elif ready=="BUSINIT: ...OK":
+                #ready=self.get_result()
+                print "Now: "+ready
+                wx.PostEvent(self._notify_window, DebugEvent([2,"0100 response2:" + ready]))
+                return None
+            
              elif ready[:2]=="41":
-                print ready
+                print "Now: "+ready
                 wx.PostEvent(self._notify_window, DebugEvent([2,"0100 response2:" + ready]))
                 return None
 
              else:             
                 #ready=ready[-5:] #Expecting error message: BUSINIT:.ERROR (parse last 5 chars)
                 wx.PostEvent(self._notify_window, DebugEvent([2,"Connection attempt failed:" + ready]))
-                time.sleep(4)
+                time.sleep(3.5)
                 if count==RECONNATTEMPTS:
                   self.close()
                   self.State = 0
@@ -169,7 +185,7 @@ class OBDPort:
      def send_command(self, cmd):
          """Internal use only: not a public interface"""
          if self.port:
-             time.sleep(0.2)
+             time.sleep(0.3)
              self.port.flushOutput()
              self.port.flushInput()
              for c in cmd:
@@ -211,7 +227,7 @@ class OBDPort:
     
      def get_result(self):
          """Internal use only: not a public interface"""
-         time.sleep(0.1)
+         time.sleep(0.2)
          if self.port:
              buffer = ""
              while 1:
@@ -372,4 +388,4 @@ class OBDPort:
                     line = "%.6f,\t%s\n" % (now - start_time, data[1])
                     file.write(line)
                     file.flush()
-          
\ No newline at end of file
+          
