@@ -190,7 +190,7 @@ class MyApp(wx.App):
         
 
         def run(self):
-
+            global btname
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connecting...."]))
             try:
                self.initCommunication()
@@ -207,6 +207,10 @@ class MyApp(wx.App):
                return None
               
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connected"]))
+            wx.PostEvent(self._notify_window, StatusEvent([3,1,self.portName]))
+            wx.PostEvent(self._notify_window, StatusEvent([4,1,btname]))
+
+
             os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Connected to ECU"')
 
             log2="echo Connected > /home/user/MyDocs/pyobd.log"
@@ -616,7 +620,7 @@ class MyApp(wx.App):
 
 
     def OnHelpAboutMaemo(self,event):
-        Text = """pyobd-0.9.2-12beta
+        Text = """pyobd-0.9.2-13
 Adapted to n900 by m750
 Now work only with BT ELM OBD devices. 
 
@@ -825,7 +829,7 @@ later version.
                   if len(btname) >= 2:
                     found=1
                     # Use the first device it finds that matches name
-                    print '    Found BT SPP dev'
+                    print ' Found BT SPP dev'
                     os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Found a BT dev. Please wait"')
 
                     target_address = btaddr
@@ -941,7 +945,7 @@ later version.
         c2=str(c1)
         c3=c2[6:18]
         ports=c3
-        print ports
+        print "Port: "+ports
         self.portName = ports
         self.btname = btname
 
